const container = d3.select("#container")
const duration = 1
const rectWidth = 300
const rectHeight = 120
const containerWidth = parseInt(container.style("width"), 10)
const containerHeight = parseInt(container.style("height"), 10)

const cardContents = [
  {
    word: `Body`,
    text: `individual
collective
identity
identification
lonely
discriminate
collaborate
isolate
value
religion
alien
race
masculine
feminin
class
normal
woke
alt-right`,
  },
  {
    word: `Audience`,
    text: `I am watching. What does it mean to watch? Am I just an eyeball? A Passive passenger watching history as it unfolds? Am I responsible for what I see? Can I become part of an activated audience? Actor and observer at the same time? What does an invitation look like?`,
  },
  {
    word: `Precarity`,
    text: `I am living in precariousness. What does it mean to live in precarious conditions? To not have a seat at the table? To lack the words, symbols, images for a real conversation? What does it mean to have no voice? What does it mean to not be heard?`,
  },
   {
    word: `Body`,
    text: `I am being exploited. What does it mean to have a body? Who owns my hands, my feet? What does it mean; a body on the street? What is a protest? How many bodies can fill a square? What language does your body speak?`,
  },
  {
    word: `Audience`,
    text: `I am watching. What does it mean to watch? Am I just an eyeball? A Passive passenger watching history as it unfolds? Am I responsible for what I see? Can I become part of an activated audience? Actor and observer at the same time? What does an invitation look like?`,
  },
  {
    word: `Precarity`,
    text: `I am living in precariousness. What does it mean to live in precarious conditions? To not have a seat at the table? To lack the words, symbols, images for a real conversation? What does it mean to have no voice? What does it mean to not be heard?`,
  },
   {
    word: `Body`,
    text: `I am being exploited. What does it mean to have a body? Who owns my hands, my feet? What does it mean; a body on the street? What is a protest? How many bodies can fill a square? What language does your body speak?`,
  },
  {
    word: `Audience`,
    text: `I am watching. What does it mean to watch? Am I just an eyeball? A Passive passenger watching history as it unfolds? Am I responsible for what I see? Can I become part of an activated audience? Actor and observer at the same time? What does an invitation look like?`,
  },
]

//Positioning logic
const originX = containerWidth/ 2;
const originY = containerHeight/ 2;
const circleRadius = 165;
const chairOriginX = originX + (circleRadius * Math.sin(0))
const chairOriginY = originY - (circleRadius * Math.cos(0))
const chairWidth = 20

const circle = container
  .append("circle")
  .attr('cx', originX)
  .attr('cy', originY)
	.attr('r', circleRadius)
	.attr('fill', 'none')
	.attr('stroke', "none")

drawCards(cardContents, container)
animate()

//This animates the text along the given path
function animate(){
  const elements = document.querySelectorAll(".masterTextPath") 
  gsap.to('#invitation', duration, {
    opacity: 1,
    delay : duration + cardContents.length
  })
  
  elements.forEach( (el, i) => {
    // console.log(el)
    gsap.from(el, duration, {
      attr: { startOffset: "100%"},
      ease: Power1.easeInOut,
      delay: 1 * i
    })
  })
}

function drawCards(contents, container){
  contents.forEach( (card, i) => {
    console.log(card)
    drawRect(card, container, i)
  })
  container.append('text')
  	.text("I think it's time we talked")
  	.attr('id', 'invitation')
  	.attr('x', containerWidth /2 - 120)
  	.attr('y', containerHeight/2)
  	.attr('fill', 'goldenrod')
  	.attr('font-size', '24')
}

//This function adds a path to our svg that we'll later use to animate text along
// It takes card data, a parent element and a unique id
function drawRect(card, parent, id){
  const rectPath = d3.path()
  rectPath.rect(0,0, rectWidth, rectHeight)
  
  //Append the path
  const path = parent.append('path')
  path
  	.attr('d',rectPath)
    .attr('id', 'master' + id)
  //Initially position the card at the top of the circle
  	.attr("transform", 
          'translate('
          +(chairOriginX - (rectWidth / 2))+','
          +(chairOriginY - rectHeight)+')')
    .attr('fill','none')
    .attr('stroke','none')
	
  //Rotate the card in relation to the circles center point
  path
  	.attr("transform", 
          `rotate( ${45 * id} , ${originX} , ${originY} ) `+
          `translate( ${(chairOriginX - (rectWidth / 2))} , ${(chairOriginY - rectHeight)} )`)

  //Append the text using an href link
  parent
    .append('text')
    .attr('id', 'mainText')
  	.attr('fill','#fff')
  	.append('textPath')
  		.attr('class', 'masterTextPath')
  		// .attr('color', 'red')
  		// .attr('stroke', 'blue')
  		.attr('href', '#master' + id)
  		// .attr('startOffset', '0%')
  		.text(card.text)
}